Processor.App.OutStreamer.stream\_to\_file.OutStreamerFileHTMLContent.\_\_init\_\_
==================================================================================

.. currentmodule:: Processor.App.OutStreamer.stream_to_file

.. automethod:: OutStreamerFileHTMLContent.__init__